@@ -56,7 +56,7 @@
 
 #define QT_FEATURE_vkkhrdisplay 1
 
-#define QT_FEATURE_egl_x11 -1
+#define QT_FEATURE_egl_x11 1
 
 #define QT_FEATURE_eglfs 1
 
@@ -78,7 +78,7 @@
 
 #define QT_FEATURE_eglfs_openwfd -1
 
-#define QT_FEATURE_eglfs_x11 -1
+#define QT_FEATURE_eglfs_x11 1
 
 #define QT_FEATURE_gif 1
 
@@ -94,29 +94,29 @@
 
 #define QT_FEATURE_imageio_text_loading 1
 
-#define QT_FEATURE_tslib -1
+#define QT_FEATURE_tslib 1
 
 #define QT_FEATURE_tuiotouch 1
 
-#define QT_FEATURE_xcb_glx -1
+#define QT_FEATURE_xcb_glx 1
 
-#define QT_FEATURE_xcb_egl_plugin -1
+#define QT_FEATURE_xcb_egl_plugin 1
 
 #define QT_FEATURE_xcb_native_painting -1
 
 #define QT_FEATURE_xrender -1
 
-#define QT_FEATURE_xcb_xlib -1
+#define QT_FEATURE_xcb_xlib 1
 
-#define QT_FEATURE_xcb_sm -1
+#define QT_FEATURE_xcb_sm 1
 
-#define QT_FEATURE_system_xcb_xinput -1
+#define QT_FEATURE_system_xcb_xinput 1
 
 #define QT_FEATURE_xkbcommon 1
 
-#define QT_FEATURE_xkbcommon_x11 -1
+#define QT_FEATURE_xkbcommon_x11 1
 
-#define QT_FEATURE_xlib -1
+#define QT_FEATURE_xlib 1
 
 #define QT_FEATURE_multiprocess 1
 
@@ -128,3 +128,5 @@
 
 #define QT_FEATURE_graphicsframecapture -1
 
+#define QT_FEATURE_run_opengl_tests 1
+
